[PATCH setup 3/4] Don't propagate actions down category tree into obsolete categories

Jon Turney jon.turney@dronecode.org.uk
Thu Mar 21 15:36:00 GMT 2019


Choosing the 'Install' action on the 'All' category shouldn't propagate
down into the '_obsolete' category, because that will just result in
dependency conflicts due to trying to install both obsolete packages and
their replacements.

Signed-off-by: Jon Turney <jon.turney@dronecode.org.uk>
---
 PickView.h | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/PickView.h b/PickView.h
index 3a6c602..3715d93 100644
--- a/PickView.h
+++ b/PickView.h
@@ -136,7 +136,10 @@ public:
              i != _bucket.end();
              i++)
           {
-            // recurse for all contained categories
+            // recurse for all contained non-obsolete categories
+            if (isObsolete((*i)->_cat.first))
+              continue;
+
             int l = (*i)->do_action(action_id, deftrust);
 
             if (!_collapsed)
-- 
2.17.0



More information about the Cygwin-apps mailing list